@@ -9,25 +9,16 @@ Created on Oct 10, 2011
 @author: tmetsch
 '''
 
-from ctypes import cast, c_char_p, c_int
-from dtrace.consumer import DTraceConsumer, deref
+from dtrace import DTraceConsumer
 
 SCRIPT = 'syscall:::entry { @num[execname] = count(); }'
 
 
-def my_walk(data, arg):
+def my_walk(id, key, value):
     '''
     Aggregate walker.
-
-    Have a look at the simple walk func in the consumer source code...
     '''
-    tmp = data.contents.dtada_data
-    name = cast(tmp + 16, c_char_p).value
-    instance = deref(tmp + 272, c_int).value
-
-    print '{0:4d} > {1:60s}'.format(instance, name)
-
-    return 0
+    print '>', id, key, value
 
 
 def main():
